@@ -136,8 +136,8 @@ reportflags :: [Flag RawOpts]
 reportflags = [
 
   -- report period & interval
-  flagReq  ["begin","b"]     (\s opts -> Right $ setopt "begin" s opts) "DATE" "include postings/txns on or after this date"
- ,flagReq  ["end","e"]       (\s opts -> Right $ setopt "end" s opts) "DATE" "include postings/txns before this date"
+  flagReq  ["begin","b"]     (\s opts -> Right $ setopt "begin" s opts) "DATE" "include postings/txns on or after this date (will be adjusted to preceding subperiod start when using a report interval)"
+ ,flagReq  ["end","e"]       (\s opts -> Right $ setopt "end" s opts) "DATE" "include postings/txns before this date (will be adjusted to following subperiod end when using a report interval)"
  ,flagNone ["daily","D"]     (setboolopt "daily") "multiperiod/multicolumn report by day"
  ,flagNone ["weekly","W"]    (setboolopt "weekly") "multiperiod/multicolumn report by week"
  ,flagNone ["monthly","M"]   (setboolopt "monthly") "multiperiod/multicolumn report by month"
@@ -190,7 +190,8 @@ reportflags = [
    ])
 
   -- general output-related
-
+  
+  -- This has special support in hledger-lib:colorOption, keep synced
  ,flagReq  ["color","colour"] (\s opts -> Right $ setopt "color" s opts) "WHEN"
    (unlines
      ["Should color-supporting commands use ANSI color codes in text output."
@@ -228,6 +229,7 @@ outputFormatFlag fmts = flagReq
   ["output-format","O"] (\s opts -> Right $ setopt "output-format" s opts) "FMT"
   ("select the output format. Supported formats:\n" ++ intercalate ", " fmts ++ ".")
 
+-- This has special support in hledger-lib:outputFileOption, keep synced
 outputFileFlag :: Flag RawOpts
 outputFileFlag = flagReq
   ["output-file","o"] (\s opts -> Right $ setopt "output-file" s opts) "FILE"
@@ -452,7 +454,7 @@ replaceNumericFlags = map replace
 -- Also records the terminal width, if supported.
 rawOptsToCliOpts :: RawOpts -> IO CliOpts
 rawOptsToCliOpts rawopts = do
-  let iopts = rawOptsToInputOpts rawopts
+  iopts <- rawOptsToInputOpts rawopts
   rspec <- rawOptsToReportSpec rawopts
   mcolumns <- readMay <$> getEnvSafe "COLUMNS"
   mtermwidth <-
@@ -555,17 +557,19 @@ expandPathPreservingPrefix d prefixedf = do
     Just p  -> p ++ ":" ++ f'
     Nothing -> f'
 
--- | Get the expanded, absolute output file path from options,
--- or the default (-, meaning stdout).
-outputFileFromOpts :: CliOpts -> IO FilePath
+-- | Get the expanded, absolute output file path specified by an
+-- -o/--output-file options, or nothing, meaning stdout.
+outputFileFromOpts :: CliOpts -> IO (Maybe FilePath)
 outputFileFromOpts opts = do
   d <- getCurrentDirectory
   case output_file_ opts of
-    Just p  -> expandPath d p
-    Nothing -> return "-"
+    Nothing -> return Nothing
+    Just f  -> Just <$> expandPath d f
 
+defaultOutputFormat :: String
 defaultOutputFormat = "txt"
 
+outputFormats :: [String]
 outputFormats =
   [defaultOutputFormat] ++
   ["csv"
