@@ -203,7 +203,7 @@ confirmedTransactionWizard prevInput es@EntryState{..} stack@(currentStage : _)
                              ,tcomment=txnCmnt
                              ,tpostings=esPostings
                              }
-      case balanceTransaction Nothing t of -- imprecise balancing (?)
+      case balanceTransaction balancingOpts t of -- imprecise balancing (?)
         Right t' ->
           confirmedTransactionWizard prevInput es (EndStage t' : stack)
         Left err -> do
@@ -233,7 +233,7 @@ confirmedTransactionWizard prevInput es@EntryState{..} stack@(currentStage : _)
   EnterAmountAndComment txnParams account -> amountAndCommentWizard prevInput es >>= \case
     Just (amount, comment) -> do
       let posting = nullposting{paccount=T.pack $ stripbrackets account
-                               ,pamount=Mixed [amount]
+                               ,pamount=mixedAmount amount
                                ,pcomment=comment
                                ,ptype=accountNamePostingType $ T.pack account
                                }
@@ -292,7 +292,7 @@ descriptionAndCommentWizard PrevInput{..} EntryState{..} = do
       return $ Just (desc, comment)
 
 postingsBalanced :: [Posting] -> Bool
-postingsBalanced ps = isRight $ balanceTransaction Nothing nulltransaction{tpostings=ps}
+postingsBalanced ps = isRight $ balanceTransaction balancingOpts nulltransaction{tpostings=ps}
 
 accountWizard PrevInput{..} EntryState{..} = do
   let pnum = length esPostings + 1
@@ -329,21 +329,20 @@ amountAndCommentWizard PrevInput{..} EntryState{..} = do
       (mhistoricalp,followedhistoricalsofar) =
           case esSimilarTransaction of
             Nothing                        -> (Nothing,False)
-            Just Transaction{tpostings=ps} -> 
+            Just Transaction{tpostings=ps} ->
               ( if length ps >= pnum then Just (ps !! (pnum-1)) else Nothing
               , all sameamount $ zip esPostings ps
               )
               where
                 sameamount (p1,p2) = mixedAmountUnstyled (pamount p1) == mixedAmountUnstyled (pamount p2)
-      def = case (esArgs, mhistoricalp, followedhistoricalsofar) of
-              (d:_,_,_)                                             -> d
-              (_,Just hp,True)                                      -> showamt $ pamount hp
-              _  | pnum > 1 && not (mixedAmountLooksZero balancingamt) -> showamt balancingamtfirstcommodity
-              _                                                     -> ""
+      def | (d:_) <- esArgs                                     = d
+          | Just hp <- mhistoricalp, followedhistoricalsofar    = showamt $ pamount hp
+          | pnum > 1 && not (mixedAmountLooksZero balancingamt) = showamt balancingamtfirstcommodity
+          | otherwise                                           = ""
   retryMsg "A valid hledger amount is required. Eg: 1, $2, 3 EUR, \"4 red apples\"." $
    parser parseAmountAndComment $
    withCompletion (amountCompleter def) $
-   defaultTo' def $ 
+   defaultTo' def $
    nonEmpty $
    linePrewritten (green $ printf "Amount  %d%s: " pnum (showDefault def)) (fromMaybe "" $ prevAmountAndCmnt `atMay` length esPostings) ""
     where
@@ -360,10 +359,9 @@ amountAndCommentWizard PrevInput{..} EntryState{..} = do
         c <- T.pack <$> fromMaybe "" `fmap` optional (char ';' >> many anySingle)
         -- eof
         return (a,c)
-      balancingamt = negate $ sum $ map pamount realps where realps = filter isReal esPostings
-      balancingamtfirstcommodity = Mixed $ take 1 $ amounts balancingamt
-      showamt =
-        showMixedAmount . mixedAmountSetPrecision
+      balancingamt = maNegate . sumPostings $ filter isReal esPostings
+      balancingamtfirstcommodity = mixed . take 1 $ amounts balancingamt
+      showamt = wbUnpack . showMixedAmountB noColour . mixedAmountSetPrecision
                   -- what should this be ?
                   -- 1 maxprecision (show all decimal places or none) ?
                   -- 2 maxprecisionwithpoint (show all decimal places or .0 - avoids some but not all confusion with thousands separators) ?
