@@ -233,7 +233,6 @@ Currently, empty cells show 0.
 
 -}
 
-{-# LANGUAGE CPP                  #-}
 {-# LANGUAGE ExtendedDefaultRules #-}
 {-# LANGUAGE NamedFieldPuns       #-}
 {-# LANGUAGE OverloadedStrings    #-}
@@ -258,17 +257,12 @@ module Hledger.Cli.Commands.Balance (
 import Data.Default (def)
 import Data.List (intersperse, transpose)
 import Data.Maybe (fromMaybe, maybeToList)
---import qualified Data.Map as Map
-#if !(MIN_VERSION_base(4,11,0))
-import Data.Semigroup ((<>))
-#endif
 import qualified Data.Text as T
 import qualified Data.Text.Lazy as TL
 import qualified Data.Text.Lazy.Builder as TB
 import Data.Time (fromGregorian)
 import System.Console.CmdArgs.Explicit as C
 import Lucid as L
-import Text.Tabular as Tab
 import Text.Tabular.AsciiWide as Tab
 
 import Hledger
@@ -319,9 +313,7 @@ balance :: CliOpts -> Journal -> IO ()
 balance opts@CliOpts{reportspec_=rspec} j = case reporttype_ of
     BudgetReport -> do  -- single or multi period budget report
       let reportspan = reportSpan j rspec
-          budgetreport = budgetReport rspec assrt reportspan j
-            where
-              assrt = not $ ignore_assertions_ $ inputopts_ opts
+          budgetreport = budgetReport rspec (balancingopts_ $ inputopts_ opts) reportspan j
           render = case fmt of
             "txt"  -> budgetReportAsText ropts
             "json" -> (<>"\n") . toJsonText
@@ -388,11 +380,11 @@ balance opts@CliOpts{reportspec_=rspec} j = case reporttype_ of
 balanceReportAsCsv :: ReportOpts -> BalanceReport -> CSV
 balanceReportAsCsv opts (items, total) =
   ["account","balance"] :
-  [[accountNameDrop (drop_ opts) a, wbToText $ showMixedAmountB oneLine b] | (a, _, _, b) <- items]
+  [[accountNameDrop (drop_ opts) a, wbToText $ showMixedAmountB (balanceOpts False opts) b] | (a, _, _, b) <- items]
   ++
   if no_total_ opts
   then []
-  else [["total", wbToText $ showMixedAmountB oneLine total]]
+  else [["total", wbToText $ showMixedAmountB (balanceOpts False opts) total]]
 
 -- | Render a single-column balance report as plain text.
 balanceReportAsText :: ReportOpts -> BalanceReport -> TB.Builder
@@ -429,11 +421,7 @@ This implementation turned out to be a bit convoluted but implements the followi
 -- The output will be one or more lines depending on the format and number of commodities.
 balanceReportItemAsText :: ReportOpts -> BalanceReportItem -> (TB.Builder, [Int])
 balanceReportItemAsText opts (_, accountName, depth, amt) =
-  renderBalanceReportItem opts (
-    accountName,
-    depth,
-    normaliseMixedAmountSquashPricesForDisplay amt
-    )
+  renderBalanceReportItem opts (accountName, depth, amt)
 
 -- | Render a balance report item using the given StringFormat, generating one or more lines of text.
 renderBalanceReportItem :: ReportOpts -> (AccountName, Int, MixedAmount) -> (TB.Builder, [Int])
@@ -461,12 +449,12 @@ renderComponent topaligned opts (acctname, depth, total) (FormatField ljust mmin
     DepthSpacerField -> Cell align [WideBuilder (TB.fromText $ T.replicate d " ") d]
                         where d = maybe id min mmax $ depth * fromMaybe 1 mmin
     AccountField     -> textCell align $ formatText ljust mmin mmax acctname
-    TotalField       -> Cell align . pure $ showamt total
+    TotalField       -> Cell align . pure $ showMixedAmountB dopts total
     _                -> Cell align [mempty]
   where
     align = if topaligned then (if ljust then TopLeft    else TopRight)
                           else (if ljust then BottomLeft else BottomRight)
-    showamt = showMixedAmountB noPrice{displayColour=color_ opts, displayMinWidth=mmin, displayMaxWidth=mmax}
+    dopts = (balanceOpts True opts){displayOneLine=False, displayMinWidth=mmin, displayMaxWidth=mmax}
 
 -- rendering multi-column balance reports
 
@@ -477,12 +465,12 @@ multiBalanceReportAsCsv :: ReportOpts -> MultiBalanceReport -> CSV
 multiBalanceReportAsCsv opts@ReportOpts{average_, row_total_}
     (PeriodicReport colspans items (PeriodicReportRow _ coltotals tot avg)) =
   maybetranspose $
-  ("Account" : map showDateSpan colspans
-   ++ ["Total"   | row_total_]
-   ++ ["Average" | average_]
+  ("account" : map showDateSpan colspans
+   ++ ["total"   | row_total_]
+   ++ ["average" | average_]
   ) :
-  [displayName a :
-   map (wbToText . showMixedAmountB oneLine)
+  [accountNameDrop (drop_ opts) (displayFull a) :
+   map (wbToText . showMixedAmountB (balanceOpts False opts))
    (amts
     ++ [rowtot | row_total_]
     ++ [rowavg | average_])
@@ -490,8 +478,8 @@ multiBalanceReportAsCsv opts@ReportOpts{average_, row_total_}
   ++
   if no_total_ opts
   then []
-  else ["Total:" :
-        map (wbToText . showMixedAmountB oneLine) (
+  else ["total" :
+        map (wbToText . showMixedAmountB (balanceOpts False opts)) (
           coltotals
           ++ [tot | row_total_]
           ++ [avg | average_]
@@ -656,13 +644,17 @@ balanceReportAsTable opts@ReportOpts{average_, row_total_, balancetype_}
 -- console output. Amounts with more than two commodities will be elided
 -- unless --no-elide is used.
 balanceReportTableAsText :: ReportOpts -> Table T.Text T.Text MixedAmount -> TB.Builder
-balanceReportTableAsText ReportOpts{..} =
+balanceReportTableAsText ropts@ReportOpts{..} =
     Tab.renderTableB def{tableBorders=False, prettyTable=pretty_tables_}
-        (Tab.textCell TopLeft) (Tab.textCell TopRight) showamt
-  where
-    showamt = Cell TopRight . pure . showMixedAmountB oneLine{displayColour=color_, displayMaxWidth=mmax}
-    mmax = if no_elide_ then Nothing else Just 32
+        (Tab.textCell TopLeft) (Tab.textCell TopRight) $
+        Cell TopRight . pure . showMixedAmountB (balanceOpts True ropts)
 
+-- | Amount display options to use for balance reports
+balanceOpts :: Bool -> ReportOpts -> AmountDisplayOpts
+balanceOpts isTable ReportOpts{..} = oneLine
+    { displayColour   = isTable && color_
+    , displayMaxWidth = if isTable && not no_elide_ then Just 32 else Nothing
+    }
 
 tests_Balance = tests "Balance" [
 
